@@ -197,6 +197,9 @@ playwith <-
     callToolbar["show-arrow"] <- FALSE
     ## merge in the address bar
     callEntry <- gtkComboBoxEntryNewText()
+    ## load session history
+    for (ihist in c(.PlaywithEnv$history, playState$history))
+        callEntry$prependText(ihist)
     callEntry$show()
     ## "changed" emitted on typing and selection
     gSignalConnect(callEntry, "changed",
@@ -490,6 +493,7 @@ doPlayReplot <- function(playState, isNewPlot = FALSE)
     if (!isNewPlot && isTRUE(playState$tmp$skip.redraws))
         return()
     playDevSet(playState)
+    devAskNewPage(FALSE) ## 'ask' is always bad because of redraws
     playState$tmp$plot.ready <- FALSE
     on.exit(playState$tmp$plot.ready <- TRUE)
     grid.newpage()
@@ -606,11 +610,14 @@ updateAddressBar <- function(playState)
             ## a new call: edited inline OR playState$call modified
             widg$callEntry$prependText(callTxt)
             widg$callEntry["active"] <- 0
-            ## remove any later history
+            ## record in history
+            playState$history <- c(playState$history, callTxt)
+            ## remove any later history (branching from a previous state)
             histLev <- playState$tmp$call.history.level
             if (any(histLev > 0)) {
                 for (i in seq(histLev-1, 0)+1)
                   widg$callEntry$removeText(i)
+                #playState$history <- head(playState$history, -histLev)
             }
         }
         playState$tmp$call.history.level <- widg$callEntry["active"]
@@ -724,15 +731,16 @@ window.close_handler <- function(widget, event, playState)
         ## if on.close() returns TRUE, do not close the window
         if (isTRUE(foo)) return(TRUE)
     }
-    if (length(playState$linked$subscribers) > 1) {
-        ans <- gconfirm("Also close linked plots?",
-                        parent = playState$win)
-        if (isTRUE(ans)) {
-            lapply(playState$linked$subscribers,
-                   playDevOff)
-            return(FALSE)
-        }
-    }
+## More annoying than useful I think:
+#    if (length(playState$linked$subscribers) > 1) {
+#        ans <- gconfirm("Also close linked plots?",
+#                        parent = playState$win)
+#        if (isTRUE(ans)) {
+#            lapply(playState$linked$subscribers,
+#                   playDevOff)
+#            return(FALSE)
+#        }
+#    }
     ## close the window and clean up
     playDevOff(playState)
     return(FALSE)
